@@ -1,20 +1,6 @@
-/* Copyright (C) 2013-2022 Greenbone Networks GmbH
+/* SPDX-FileCopyrightText: 2013-2023 Greenbone AG
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 /**
@@ -28,6 +14,11 @@
 #ifndef _GVM_HOSTS_H
 #define _GVM_HOSTS_H
 
+/** @brief Flag that indecates that this version includes
+ *  the function gvm_hosts_allowed_only()
+ */
+#define FEATURE_HOSTS_ALLOWED_ONLY 1
+
 #include <glib.h>       /* for gchar, GList */
 #include <netinet/in.h> /* for in6_addr, in_addr */
 
@@ -138,6 +129,9 @@ gvm_vhosts_exclude (gvm_host_t *, const char *);
 int
 gvm_hosts_exclude_with_max (gvm_hosts_t *, const char *, unsigned int);
 
+GSList *
+gvm_hosts_allowed_only (gvm_hosts_t *, const char *, const char *);
+
 char *
 gvm_host_reverse_lookup (gvm_host_t *);
 
