@@ -1,20 +1,6 @@
-/* Copyright (C) 2017-2022 Greenbone Networks GmbH
+/* SPDX-FileCopyrightText: 2017-2023 Greenbone AG
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 /**
@@ -383,6 +369,57 @@ gvm_log_unlock (void)
   g_mutex_unlock (logger_mutex);
 }
 
+static char *reference = NULL;
+
+/**
+ * @brief Set the log reference object.
+ *
+ * In order to be able to see which logs are related to each other, we define a
+ * common reference for them. E.g. when multiple scans in OpenVAS are running
+ * simultaniousely it is possible to detect all log corresponding to the same
+ * scan. The log reference is optional and must be set before calling
+ * setup_log_handlers. The data given must be freed by calling
+ * free_log_reference(). If called multiple times the old reference gets freed
+ * and the new one is set instead.
+ *
+ * @param ref
+ */
+void
+set_log_reference (char *ref)
+{
+  if (reference)
+    g_free ((char *) reference);
+  reference = ref;
+}
+
+/**
+ * @brief Get the log reference object
+ *
+ * This function returns the current log reference. This enables the possibility
+ * to save or modify the current reference value.
+ *
+ * @return char*
+ */
+char *
+get_log_reference (void)
+{
+  return (char *) reference;
+}
+
+/**
+ * @brief Free the log reference object
+ *
+ * The reference object is used to detect corresponding logs.
+ *
+ */
+void
+free_log_reference (void)
+{
+  if (reference)
+    g_free ((char *) reference);
+  reference = NULL;
+}
+
 /**
  * @brief Creates the formatted string and outputs it to the log destination.
  *
@@ -524,9 +561,19 @@ gvm_log_func (const char *log_domain, GLogLevelFlags log_level,
       /* If the current char is a % and the next one is a p, get the pid. */
       if ((*tmp == '%') && (*(tmp + 1) == 'p'))
         {
-          /* Use g_strdup, a new string returned. Store it in a tmp var until
-           * we free the old one. */
-          prepend_tmp = g_strdup_printf ("%s%d", prepend_buf, (int) getpid ());
+          if (reference)
+            {
+              prepend_tmp =
+                g_strdup_printf ("%s%d%s%s", prepend_buf, (int) getpid (),
+                                 log_separator, reference);
+            }
+          else
+            {
+              /* Use g_strdup, a new string returned. Store it in a tmp var
+               * until we free the old one. */
+              prepend_tmp =
+                g_strdup_printf ("%s%d", prepend_buf, (int) getpid ());
+            }
           /* Free the old string. */
           g_free (prepend_buf);
           /* Point the buf ptr to the new string. */
