@@ -1,20 +1,6 @@
-/* Copyright (C) 2009-2022 Greenbone Networks GmbH
+/* SPDX-FileCopyrightText: 2009-2023 Greenbone AG
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 //  One of the files of gvm-libs needs to specify the meta data
@@ -1294,6 +1280,26 @@ nvti_set_name (nvti_t *n, const gchar *name)
   return 0;
 }
 
+/**
+ * @brief Set the name of a NVT, using the given memory.
+ *
+ * @param n The NVT Info structure.
+ *
+ * @param name The name to set. The string will be used directly.
+ *
+ * @return 0 for success. Anything else indicates an error.
+ */
+int
+nvti_put_name (nvti_t *n, gchar *name)
+{
+  if (!n)
+    return -1;
+
+  g_free (n->name);
+  n->name = name;
+  return 0;
+}
+
 /**
  * @brief Set the summary of a NVT.
  *
@@ -1314,6 +1320,26 @@ nvti_set_summary (nvti_t *n, const gchar *summary)
   return 0;
 }
 
+/**
+ * @brief Set the summary of a NVT, using the given memory.
+ *
+ * @param n The NVT Info structure.
+ *
+ * @param solution The summary to set. The string will be used directly.
+ *
+ * @return 0 for success. Anything else indicates an error.
+ */
+int
+nvti_put_summary (nvti_t *n, gchar *summary)
+{
+  if (!n)
+    return -1;
+
+  g_free (n->summary);
+  n->summary = summary;
+  return 0;
+}
+
 /**
  * @brief Set the insight text of a NVT.
  *
@@ -1334,6 +1360,26 @@ nvti_set_insight (nvti_t *n, const gchar *insight)
   return 0;
 }
 
+/**
+ * @brief Set the insight text of a NVT, using the given memory.
+ *
+ * @param n The NVT Info structure.
+ *
+ * @param insight The insight text to set. The string will be used directly.
+ *
+ * @return 0 for success. Anything else indicates an error.
+ */
+int
+nvti_put_insight (nvti_t *n, gchar *insight)
+{
+  if (!n)
+    return -1;
+
+  g_free (n->insight);
+  n->insight = insight;
+  return 0;
+}
+
 /**
  * @brief Set the affected text of a NVT.
  *
@@ -1354,6 +1400,26 @@ nvti_set_affected (nvti_t *n, const gchar *affected)
   return 0;
 }
 
+/**
+ * @brief Set the affected text of a NVT, using the given memory.
+ *
+ * @param n The NVT Info structure.
+ *
+ * @param affected The affected text to set. The string will be used directly.
+ *
+ * @return 0 for success. Anything else indicates an error.
+ */
+int
+nvti_put_affected (nvti_t *n, gchar *affected)
+{
+  if (!n)
+    return -1;
+
+  g_free (n->affected);
+  n->affected = affected;
+  return 0;
+}
+
 /**
  * @brief Set the impact text of a NVT.
  *
@@ -1374,6 +1440,26 @@ nvti_set_impact (nvti_t *n, const gchar *impact)
   return 0;
 }
 
+/**
+ * @brief Set the impact text of a NVT, using the given memory.
+ *
+ * @param n The NVT Info structure.
+ *
+ * @param affected The impact text to set. The string will be used directly.
+ *
+ * @return 0 for success. Anything else indicates an error.
+ */
+int
+nvti_put_impact (nvti_t *n, gchar *impact)
+{
+  if (!n)
+    return -1;
+
+  g_free (n->impact);
+  n->impact = impact;
+  return 0;
+}
+
 /**
  * @brief Set the creation time of a NVT.
  *
@@ -1432,6 +1518,26 @@ nvti_set_solution (nvti_t *n, const gchar *solution)
   return 0;
 }
 
+/**
+ * @brief Set the solution of a NVT, using the given memory.
+ *
+ * @param n The NVT Info structure.
+ *
+ * @param solution The solution to set. The string will be used directly.
+ *
+ * @return 0 for success. Anything else indicates an error.
+ */
+int
+nvti_put_solution (nvti_t *n, gchar *solution)
+{
+  if (!n)
+    return -1;
+
+  g_free (n->solution);
+  n->solution = solution;
+  return 0;
+}
+
 /**
  * @brief Set the solution type of a NVT.
  *
@@ -1755,6 +1861,26 @@ nvti_set_detection (nvti_t *n, const gchar *detection)
   return 0;
 }
 
+/**
+ * @brief Set the detection text of a NVT, using the given memory.
+ *
+ * @param n The NVT Info structure.
+ *
+ * @param detection The detection text to set. The string will be used directly.
+ *
+ * @return 0 for success. Anything else indicates an error.
+ */
+int
+nvti_put_detection (nvti_t *n, gchar *detection)
+{
+  if (!n)
+    return -1;
+
+  g_free (n->detection);
+  n->detection = detection;
+  return 0;
+}
+
 /**
  * @brief Set the QoD type of a NVT.
  *
@@ -1823,6 +1949,26 @@ nvti_set_family (nvti_t *n, const gchar *family)
   return 0;
 }
 
+/**
+ * @brief Set the family of a NVT, using the given memory.
+ *
+ * @param n The NVT Info structure.
+ *
+ * @param family The family to set. The string will be used directly.
+ *
+ * @return 0 for success. Anything else indicates an error.
+ */
+int
+nvti_put_family (nvti_t *n, gchar *family)
+{
+  if (!n)
+    return -1;
+
+  g_free (n->family);
+  n->family = family;
+  return 0;
+}
+
 /**
  * @brief Set the category type of a NVT Info.
  *
